summaryrefslogtreecommitdiff
path: root/src/ipcpd
diff options
context:
space:
mode:
authorDimitri Staessens <dimitri@ouroboros.rocks>2019-07-25 12:50:46 +0200
committerSander Vrijders <sander@ouroboros.rocks>2019-07-29 19:36:45 +0200
commitdae15c284248d49079ad5f8a3d8ff30e217f419e (patch)
treeea7942e940396c0c78304fef8b43fb25c5aebba8 /src/ipcpd
parentc9232acef855b51d1bc199a68c03c0695ac11192 (diff)
downloadouroboros-dae15c284248d49079ad5f8a3d8ff30e217f419e.tar.gz
ouroboros-dae15c284248d49079ad5f8a3d8ff30e217f419e.zip
build: Refactor normal to unicast
This completes the renaming of the normal IPCP to the unicast IPCP in the sources, to get everything consistent with the documentation. Signed-off-by: Dimitri Staessens <dimitri@ouroboros.rocks> Signed-off-by: Sander Vrijders <sander@ouroboros.rocks>
Diffstat (limited to 'src/ipcpd')
-rw-r--r--src/ipcpd/CMakeLists.txt8
-rw-r--r--src/ipcpd/ipcp.c2
-rw-r--r--src/ipcpd/unicast/CMakeLists.txt (renamed from src/ipcpd/normal/CMakeLists.txt)10
-rw-r--r--src/ipcpd/unicast/addr_auth.c (renamed from src/ipcpd/normal/addr_auth.c)0
-rw-r--r--src/ipcpd/unicast/addr_auth.h (renamed from src/ipcpd/normal/addr_auth.h)6
-rw-r--r--src/ipcpd/unicast/comp.h (renamed from src/ipcpd/normal/comp.h)8
-rw-r--r--src/ipcpd/unicast/connmgr.c (renamed from src/ipcpd/normal/connmgr.c)0
-rw-r--r--src/ipcpd/unicast/connmgr.h (renamed from src/ipcpd/normal/connmgr.h)6
-rw-r--r--src/ipcpd/unicast/dht.c (renamed from src/ipcpd/normal/dht.c)0
-rw-r--r--src/ipcpd/unicast/dht.h (renamed from src/ipcpd/normal/dht.h)6
-rw-r--r--src/ipcpd/unicast/dir.c (renamed from src/ipcpd/normal/dir.c)0
-rw-r--r--src/ipcpd/unicast/dir.h (renamed from src/ipcpd/normal/dir.h)6
-rw-r--r--src/ipcpd/unicast/dt.c (renamed from src/ipcpd/normal/dt.c)0
-rw-r--r--src/ipcpd/unicast/dt.h (renamed from src/ipcpd/normal/dt.h)6
-rw-r--r--src/ipcpd/unicast/enroll.c (renamed from src/ipcpd/normal/enroll.c)0
-rw-r--r--src/ipcpd/unicast/enroll.h (renamed from src/ipcpd/normal/enroll.h)6
-rw-r--r--src/ipcpd/unicast/fa.c (renamed from src/ipcpd/normal/fa.c)0
-rw-r--r--src/ipcpd/unicast/fa.h (renamed from src/ipcpd/normal/fa.h)6
-rw-r--r--src/ipcpd/unicast/kademlia.proto (renamed from src/ipcpd/normal/kademlia.proto)0
-rw-r--r--src/ipcpd/unicast/main.c (renamed from src/ipcpd/normal/main.c)24
-rw-r--r--src/ipcpd/unicast/pff.c (renamed from src/ipcpd/normal/pff.c)0
-rw-r--r--src/ipcpd/unicast/pff.h (renamed from src/ipcpd/normal/pff.h)6
-rw-r--r--src/ipcpd/unicast/pol-addr-auth-ops.h (renamed from src/ipcpd/normal/pol-addr-auth-ops.h)6
-rw-r--r--src/ipcpd/unicast/pol-pff-ops.h (renamed from src/ipcpd/normal/pol-pff-ops.h)6
-rw-r--r--src/ipcpd/unicast/pol-routing-ops.h (renamed from src/ipcpd/normal/pol-routing-ops.h)6
-rw-r--r--src/ipcpd/unicast/pol/alternate_pff.c (renamed from src/ipcpd/normal/pol/alternate_pff.c)0
-rw-r--r--src/ipcpd/unicast/pol/alternate_pff.h (renamed from src/ipcpd/normal/pol/alternate_pff.h)6
-rw-r--r--src/ipcpd/unicast/pol/flat.c (renamed from src/ipcpd/normal/pol/flat.c)0
-rw-r--r--src/ipcpd/unicast/pol/flat.h (renamed from src/ipcpd/normal/pol/flat.h)6
-rw-r--r--src/ipcpd/unicast/pol/graph.c (renamed from src/ipcpd/normal/pol/graph.c)2
-rw-r--r--src/ipcpd/unicast/pol/graph.h (renamed from src/ipcpd/normal/pol/graph.h)6
-rw-r--r--src/ipcpd/unicast/pol/link_state.c (renamed from src/ipcpd/normal/pol/link_state.c)0
-rw-r--r--src/ipcpd/unicast/pol/link_state.h (renamed from src/ipcpd/normal/pol/link_state.h)6
-rw-r--r--src/ipcpd/unicast/pol/simple_pff.c (renamed from src/ipcpd/normal/pol/simple_pff.c)0
-rw-r--r--src/ipcpd/unicast/pol/simple_pff.h (renamed from src/ipcpd/normal/pol/simple_pff.h)6
-rw-r--r--src/ipcpd/unicast/pol/tests/CMakeLists.txt (renamed from src/ipcpd/normal/pol/tests/CMakeLists.txt)0
-rw-r--r--src/ipcpd/unicast/pol/tests/graph_test.c (renamed from src/ipcpd/normal/pol/tests/graph_test.c)0
-rw-r--r--src/ipcpd/unicast/psched.c (renamed from src/ipcpd/normal/psched.c)0
-rw-r--r--src/ipcpd/unicast/psched.h (renamed from src/ipcpd/normal/psched.h)6
-rw-r--r--src/ipcpd/unicast/routing.c (renamed from src/ipcpd/normal/routing.c)0
-rw-r--r--src/ipcpd/unicast/routing.h (renamed from src/ipcpd/normal/routing.h)6
-rw-r--r--src/ipcpd/unicast/tests/CMakeLists.txt (renamed from src/ipcpd/normal/tests/CMakeLists.txt)0
-rw-r--r--src/ipcpd/unicast/tests/dht_test.c (renamed from src/ipcpd/normal/tests/dht_test.c)0
43 files changed, 81 insertions, 81 deletions
diff --git a/src/ipcpd/CMakeLists.txt b/src/ipcpd/CMakeLists.txt
index 5c109b46..d0b368a3 100644
--- a/src/ipcpd/CMakeLists.txt
+++ b/src/ipcpd/CMakeLists.txt
@@ -40,12 +40,12 @@ set(IPCP_SOURCES
${CMAKE_CURRENT_SOURCE_DIR}/shim-data.c
)
-add_subdirectory(broadcast)
add_subdirectory(local)
-add_subdirectory(normal)
-add_subdirectory(raptor)
-add_subdirectory(udp)
add_subdirectory(eth)
+add_subdirectory(udp)
+add_subdirectory(raptor)
+add_subdirectory(unicast)
+add_subdirectory(broadcast)
configure_file("${CMAKE_CURRENT_SOURCE_DIR}/config.h.in"
"${CMAKE_CURRENT_BINARY_DIR}/config.h" @ONLY)
diff --git a/src/ipcpd/ipcp.c b/src/ipcpd/ipcp.c
index 25c1b368..86b78760 100644
--- a/src/ipcpd/ipcp.c
+++ b/src/ipcpd/ipcp.c
@@ -235,7 +235,7 @@ static void * mainloop(void * o)
switch(conf_msg->ipcp_type) {
case IPCP_LOCAL:
break;
- case IPCP_NORMAL:
+ case IPCP_UNICAST:
conf.addr_size = conf_msg->addr_size;
conf.eid_size = conf_msg->eid_size;
conf.max_ttl = conf_msg->max_ttl;
diff --git a/src/ipcpd/normal/CMakeLists.txt b/src/ipcpd/unicast/CMakeLists.txt
index d1585395..c9344f89 100644
--- a/src/ipcpd/normal/CMakeLists.txt
+++ b/src/ipcpd/unicast/CMakeLists.txt
@@ -12,7 +12,7 @@ include_directories(${CURRENT_BINARY_PARENT_DIR})
include_directories(${CMAKE_SOURCE_DIR}/include)
include_directories(${CMAKE_BINARY_DIR}/include)
-set(IPCP_NORMAL_TARGET ipcpd-normal CACHE INTERNAL "")
+set(IPCP_UNICAST_TARGET ipcpd-unicast CACHE INTERNAL "")
protobuf_generate_c(KAD_PROTO_SRCS KAD_PROTO_HDRS kademlia.proto)
@@ -51,16 +51,16 @@ set(SOURCE_FILES
pol/simple_pff.c
)
-add_executable(ipcpd-normal ${SOURCE_FILES} ${IPCP_SOURCES}
+add_executable(ipcpd-unicast ${SOURCE_FILES} ${IPCP_SOURCES}
${KAD_PROTO_SRCS} ${LAYER_CONFIG_PROTO_SRCS})
-target_link_libraries(ipcpd-normal LINK_PUBLIC ouroboros-dev)
+target_link_libraries(ipcpd-unicast LINK_PUBLIC ouroboros-dev)
include(AddCompileFlags)
if (CMAKE_BUILD_TYPE MATCHES "Debug*")
- add_compile_flags(ipcpd-normal -DCONFIG_OUROBOROS_DEBUG)
+ add_compile_flags(ipcpd-unicast -DCONFIG_OUROBOROS_DEBUG)
endif ()
-install(TARGETS ipcpd-normal RUNTIME DESTINATION ${CMAKE_INSTALL_SBINDIR})
+install(TARGETS ipcpd-unicast RUNTIME DESTINATION ${CMAKE_INSTALL_SBINDIR})
add_subdirectory(pol/tests)
diff --git a/src/ipcpd/normal/addr_auth.c b/src/ipcpd/unicast/addr_auth.c
index 50c56055..50c56055 100644
--- a/src/ipcpd/normal/addr_auth.c
+++ b/src/ipcpd/unicast/addr_auth.c
diff --git a/src/ipcpd/normal/addr_auth.h b/src/ipcpd/unicast/addr_auth.h
index e205b50a..cf1509ab 100644
--- a/src/ipcpd/normal/addr_auth.h
+++ b/src/ipcpd/unicast/addr_auth.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_ADDR_AUTH_H
-#define OUROBOROS_IPCPD_NORMAL_ADDR_AUTH_H
+#ifndef OUROBOROS_IPCPD_UNICAST_ADDR_AUTH_H
+#define OUROBOROS_IPCPD_UNICAST_ADDR_AUTH_H
#include <ouroboros/ipcp.h>
@@ -34,4 +34,4 @@ int addr_auth_fini(void);
uint64_t addr_auth_address(void);
-#endif /* OUROBOROS_IPCPD_NORMAL_ADDR_AUTH_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_ADDR_AUTH_H */
diff --git a/src/ipcpd/normal/comp.h b/src/ipcpd/unicast/comp.h
index 029c2d7a..b8294c3b 100644
--- a/src/ipcpd/normal/comp.h
+++ b/src/ipcpd/unicast/comp.h
@@ -1,7 +1,7 @@
/*
* Ouroboros - Copyright (C) 2016 - 2019
*
- * Components for the normal IPC process
+ * Components for the unicast IPC process
*
* Dimitri Staessens <dimitri.staessens@ugent.be>
* Sander Vrijders <sander.vrijders@ugent.be>
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_COMP_H
-#define OUROBOROS_IPCPD_NORMAL_COMP_H
+#ifndef OUROBOROS_IPCPD_UNICAST_COMP_H
+#define OUROBOROS_IPCPD_UNICAST_COMP_H
#include <ouroboros/cacep.h>
@@ -45,4 +45,4 @@ struct conn {
} flow_info;
};
-#endif /* OUROBOROS_IPCPD_NORMAL_COMP_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_COMP_H */
diff --git a/src/ipcpd/normal/connmgr.c b/src/ipcpd/unicast/connmgr.c
index 7c1280c3..7c1280c3 100644
--- a/src/ipcpd/normal/connmgr.c
+++ b/src/ipcpd/unicast/connmgr.c
diff --git a/src/ipcpd/normal/connmgr.h b/src/ipcpd/unicast/connmgr.h
index 4f81ff9d..44a3fe39 100644
--- a/src/ipcpd/normal/connmgr.h
+++ b/src/ipcpd/unicast/connmgr.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_CONNMGR_H
-#define OUROBOROS_IPCPD_NORMAL_CONNMGR_H
+#ifndef OUROBOROS_IPCPD_UNICAST_CONNMGR_H
+#define OUROBOROS_IPCPD_UNICAST_CONNMGR_H
#include <ouroboros/cacep.h>
#include <ouroboros/qos.h>
@@ -71,4 +71,4 @@ int connmgr_dealloc(enum comp_id id,
int connmgr_wait(enum comp_id id,
struct conn * conn);
-#endif /* OUROBOROS_IPCPD_NORMAL_CONNMGR_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_CONNMGR_H */
diff --git a/src/ipcpd/normal/dht.c b/src/ipcpd/unicast/dht.c
index f24a2c51..f24a2c51 100644
--- a/src/ipcpd/normal/dht.c
+++ b/src/ipcpd/unicast/dht.c
diff --git a/src/ipcpd/normal/dht.h b/src/ipcpd/unicast/dht.h
index 519b29d4..7d7601f5 100644
--- a/src/ipcpd/normal/dht.h
+++ b/src/ipcpd/unicast/dht.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_DHT_H
-#define OUROBOROS_IPCPD_NORMAL_DHT_H
+#ifndef OUROBOROS_IPCPD_UNICAST_DHT_H
+#define OUROBOROS_IPCPD_UNICAST_DHT_H
#include <ouroboros/ipcp-dev.h>
@@ -49,4 +49,4 @@ uint64_t dht_query(struct dht * dht,
int dht_wait_running(struct dht * dht);
-#endif /* OUROBOROS_IPCPD_NORMAL_DHT_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_DHT_H */
diff --git a/src/ipcpd/normal/dir.c b/src/ipcpd/unicast/dir.c
index 3b0446fa..3b0446fa 100644
--- a/src/ipcpd/normal/dir.c
+++ b/src/ipcpd/unicast/dir.c
diff --git a/src/ipcpd/normal/dir.h b/src/ipcpd/unicast/dir.h
index 78e82e33..8aba8b1d 100644
--- a/src/ipcpd/normal/dir.h
+++ b/src/ipcpd/unicast/dir.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_DIR_H
-#define OUROBOROS_IPCPD_NORMAL_DIR_H
+#ifndef OUROBOROS_IPCPD_UNICAST_DIR_H
+#define OUROBOROS_IPCPD_UNICAST_DIR_H
int dir_init(void);
@@ -37,4 +37,4 @@ uint64_t dir_query(const uint8_t * hash);
int dir_wait_running(void);
-#endif /* OUROBOROS_IPCPD_NORMAL_DIR_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_DIR_H */
diff --git a/src/ipcpd/normal/dt.c b/src/ipcpd/unicast/dt.c
index 2fd3c060..2fd3c060 100644
--- a/src/ipcpd/normal/dt.c
+++ b/src/ipcpd/unicast/dt.c
diff --git a/src/ipcpd/normal/dt.h b/src/ipcpd/unicast/dt.h
index 89610471..5f2ee1a5 100644
--- a/src/ipcpd/normal/dt.h
+++ b/src/ipcpd/unicast/dt.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_DT_H
-#define OUROBOROS_IPCPD_NORMAL_DT_H
+#ifndef OUROBOROS_IPCPD_UNICAST_DT_H
+#define OUROBOROS_IPCPD_UNICAST_DT_H
#include <ouroboros/ipcp.h>
#include <ouroboros/qoscube.h>
@@ -53,4 +53,4 @@ int dt_write_packet(uint64_t dst_addr,
int res_fd,
struct shm_du_buff * sdb);
-#endif /* OUROBOROS_IPCPD_NORMAL_DT_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_DT_H */
diff --git a/src/ipcpd/normal/enroll.c b/src/ipcpd/unicast/enroll.c
index b572f89d..b572f89d 100644
--- a/src/ipcpd/normal/enroll.c
+++ b/src/ipcpd/unicast/enroll.c
diff --git a/src/ipcpd/normal/enroll.h b/src/ipcpd/unicast/enroll.h
index fd662db1..0a1ce5fc 100644
--- a/src/ipcpd/normal/enroll.h
+++ b/src/ipcpd/unicast/enroll.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_ENROLL_H
-#define OUROBOROS_IPCPD_NORMAL_ENROLL_H
+#ifndef OUROBOROS_IPCPD_UNICAST_ENROLL_H
+#define OUROBOROS_IPCPD_UNICAST_ENROLL_H
#include <ouroboros/ipcp.h>
@@ -44,4 +44,4 @@ int enroll_done(struct conn * conn,
struct ipcp_config * enroll_get_conf(void);
-#endif /* OUROBOROS_IPCPD_NORMAL_ENROLL_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_ENROLL_H */
diff --git a/src/ipcpd/normal/fa.c b/src/ipcpd/unicast/fa.c
index fbcbc6fa..fbcbc6fa 100644
--- a/src/ipcpd/normal/fa.c
+++ b/src/ipcpd/unicast/fa.c
diff --git a/src/ipcpd/normal/fa.h b/src/ipcpd/unicast/fa.h
index d1ec72df..ea055ec2 100644
--- a/src/ipcpd/normal/fa.h
+++ b/src/ipcpd/unicast/fa.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_FA_H
-#define OUROBOROS_IPCPD_NORMAL_FA_H
+#ifndef OUROBOROS_IPCPD_UNICAST_FA_H
+#define OUROBOROS_IPCPD_UNICAST_FA_H
#include <ouroboros/qos.h>
#include <ouroboros/utils.h>
@@ -43,4 +43,4 @@ int fa_alloc_resp(int fd,
int fa_dealloc(int fd);
-#endif /* OUROBOROS_IPCPD_NORMAL_FA_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_FA_H */
diff --git a/src/ipcpd/normal/kademlia.proto b/src/ipcpd/unicast/kademlia.proto
index 6bd78b38..6bd78b38 100644
--- a/src/ipcpd/normal/kademlia.proto
+++ b/src/ipcpd/unicast/kademlia.proto
diff --git a/src/ipcpd/normal/pff.c b/src/ipcpd/unicast/pff.c
index 5b1fa429..5b1fa429 100644
--- a/src/ipcpd/normal/pff.c
+++ b/src/ipcpd/unicast/pff.c
diff --git a/src/ipcpd/normal/pff.h b/src/ipcpd/unicast/pff.h
index 721899b2..9533395f 100644
--- a/src/ipcpd/normal/pff.h
+++ b/src/ipcpd/unicast/pff.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_PFF_H
-#define OUROBOROS_IPCPD_NORMAL_PFF_H
+#ifndef OUROBOROS_IPCPD_UNICAST_PFF_H
+#define OUROBOROS_IPCPD_UNICAST_PFF_H
#include <ouroboros/ipcp.h>
@@ -60,4 +60,4 @@ int pff_flow_state_change(struct pff * pff,
int fd,
bool up);
-#endif /* OUROBOROS_IPCPD_NORMAL_PFF_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_PFF_H */
diff --git a/src/ipcpd/normal/pol-addr-auth-ops.h b/src/ipcpd/unicast/pol-addr-auth-ops.h
index ed7ba450..7b1a4514 100644
--- a/src/ipcpd/normal/pol-addr-auth-ops.h
+++ b/src/ipcpd/unicast/pol-addr-auth-ops.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_POL_ADDR_AUTH_OPS_H
-#define OUROBOROS_IPCPD_NORMAL_POL_ADDR_AUTH_OPS_H
+#ifndef OUROBOROS_IPCPD_UNICAST_POL_ADDR_AUTH_OPS_H
+#define OUROBOROS_IPCPD_UNICAST_POL_ADDR_AUTH_OPS_H
struct pol_addr_auth_ops {
int (* init)(const void * info);
@@ -31,4 +31,4 @@ struct pol_addr_auth_ops {
uint64_t (* address)(void);
};
-#endif /* OUROBOROS_IPCPD_NORMAL_POL_ADDR_AUTH_OPS_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_POL_ADDR_AUTH_OPS_H */
diff --git a/src/ipcpd/normal/pol-pff-ops.h b/src/ipcpd/unicast/pol-pff-ops.h
index 269000e8..766bb5b8 100644
--- a/src/ipcpd/normal/pol-pff-ops.h
+++ b/src/ipcpd/unicast/pol-pff-ops.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_POL_PFF_OPS_H
-#define OUROBOROS_IPCPD_NORMAL_POL_PFF_OPS_H
+#ifndef OUROBOROS_IPCPD_UNICAST_POL_PFF_OPS_H
+#define OUROBOROS_IPCPD_UNICAST_POL_PFF_OPS_H
#include <stdbool.h>
@@ -60,4 +60,4 @@ struct pol_pff_ops {
bool up);
};
-#endif /* OUROBOROS_IPCPD_NORMAL_POL_PFF_OPS_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_POL_PFF_OPS_H */
diff --git a/src/ipcpd/normal/pol-routing-ops.h b/src/ipcpd/unicast/pol-routing-ops.h
index 9ffb2d35..ae8e632d 100644
--- a/src/ipcpd/normal/pol-routing-ops.h
+++ b/src/ipcpd/unicast/pol-routing-ops.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_POL_ROUTING_OPS_H
-#define OUROBOROS_IPCPD_NORMAL_POL_ROUTING_OPS_H
+#ifndef OUROBOROS_IPCPD_UNICAST_POL_ROUTING_OPS_H
+#define OUROBOROS_IPCPD_UNICAST_POL_ROUTING_OPS_H
#include "pff.h"
@@ -35,4 +35,4 @@ struct pol_routing_ops {
void (* routing_i_destroy)(struct routing_i * instance);
};
-#endif /* OUROBOROS_IPCPD_NORMAL_POL_ROUTING_OPS_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_POL_ROUTING_OPS_H */
diff --git a/src/ipcpd/normal/pol/alternate_pff.c b/src/ipcpd/unicast/pol/alternate_pff.c
index 38937297..38937297 100644
--- a/src/ipcpd/normal/pol/alternate_pff.c
+++ b/src/ipcpd/unicast/pol/alternate_pff.c
diff --git a/src/ipcpd/normal/pol/alternate_pff.h b/src/ipcpd/unicast/pol/alternate_pff.h
index 3bfbb886..7bdf26de 100644
--- a/src/ipcpd/normal/pol/alternate_pff.h
+++ b/src/ipcpd/unicast/pol/alternate_pff.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_ALTERNATE_PFF_H
-#define OUROBOROS_IPCPD_NORMAL_ALTERNATE_PFF_H
+#ifndef OUROBOROS_IPCPD_UNICAST_ALTERNATE_PFF_H
+#define OUROBOROS_IPCPD_UNICAST_ALTERNATE_PFF_H
#include "pol-pff-ops.h"
@@ -58,4 +58,4 @@ int alternate_flow_state_change(struct pff_i * pff_i,
struct pol_pff_ops alternate_pff_ops;
-#endif /* OUROBOROS_IPCPD_NORMAL_ALTERNATE_PFF_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_ALTERNATE_PFF_H */
diff --git a/src/ipcpd/normal/pol/flat.c b/src/ipcpd/unicast/pol/flat.c
index 157885f9..157885f9 100644
--- a/src/ipcpd/normal/pol/flat.c
+++ b/src/ipcpd/unicast/pol/flat.c
diff --git a/src/ipcpd/normal/pol/flat.h b/src/ipcpd/unicast/pol/flat.h
index 9df3de51..64aa9ce0 100644
--- a/src/ipcpd/normal/pol/flat.h
+++ b/src/ipcpd/unicast/pol/flat.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_FLAT_H
-#define OUROBOROS_IPCPD_NORMAL_FLAT_H
+#ifndef OUROBOROS_IPCPD_UNICAST_FLAT_H
+#define OUROBOROS_IPCPD_UNICAST_FLAT_H
#include "pol-addr-auth-ops.h"
@@ -33,4 +33,4 @@ uint64_t flat_address(void);
struct pol_addr_auth_ops flat_ops;
-#endif /* OUROBOROS_IPCPD_NORMAL_FLAT_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_FLAT_H */
diff --git a/src/ipcpd/normal/pol/graph.c b/src/ipcpd/unicast/pol/graph.c
index 6c93bb62..499dc2de 100644
--- a/src/ipcpd/normal/pol/graph.c
+++ b/src/ipcpd/unicast/pol/graph.c
@@ -601,7 +601,7 @@ int graph_routing_table(struct graph * graph,
pthread_mutex_lock(&graph->lock);
- /* Get the normal next hops routing table. */
+ /* Get the simple next hops routing table. */
if (graph_routing_table_simple(graph, s_addr, table, &s_dist))
goto fail_table_simple;
diff --git a/src/ipcpd/normal/pol/graph.h b/src/ipcpd/unicast/pol/graph.h
index 131e9eca..06a2bd0d 100644
--- a/src/ipcpd/normal/pol/graph.h
+++ b/src/ipcpd/unicast/pol/graph.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_GRAPH_H
-#define OUROBOROS_IPCPD_NORMAL_GRAPH_H
+#ifndef OUROBOROS_IPCPD_UNICAST_GRAPH_H
+#define OUROBOROS_IPCPD_UNICAST_GRAPH_H
#include <ouroboros/list.h>
#include <ouroboros/qos.h>
@@ -65,4 +65,4 @@ int graph_routing_table(struct graph * graph,
void graph_free_routing_table(struct graph * graph,
struct list_head * table);
-#endif /* OUROBOROS_IPCPD_NORMAL_GRAPH_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_GRAPH_H */
diff --git a/src/ipcpd/normal/pol/link_state.c b/src/ipcpd/unicast/pol/link_state.c
index d8f0e263..d8f0e263 100644
--- a/src/ipcpd/normal/pol/link_state.c
+++ b/src/ipcpd/unicast/pol/link_state.c
diff --git a/src/ipcpd/normal/pol/link_state.h b/src/ipcpd/unicast/pol/link_state.h
index 3fcb03ff..a7b44b4e 100644
--- a/src/ipcpd/normal/pol/link_state.h
+++ b/src/ipcpd/unicast/pol/link_state.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_POL_LINK_STATE_H
-#define OUROBOROS_IPCPD_NORMAL_POL_LINK_STATE_H
+#ifndef OUROBOROS_IPCPD_UNICAST_POL_LINK_STATE_H
+#define OUROBOROS_IPCPD_UNICAST_POL_LINK_STATE_H
#define LS_COMP "Management"
#define LS_PROTO "LSP"
@@ -38,4 +38,4 @@ void link_state_routing_i_destroy(struct routing_i * instance);
struct pol_routing_ops link_state_ops;
-#endif /* OUROBOROS_IPCPD_NORMAL_POL_LINK_STATE_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_POL_LINK_STATE_H */
diff --git a/src/ipcpd/normal/pol/simple_pff.c b/src/ipcpd/unicast/pol/simple_pff.c
index 4338c53c..4338c53c 100644
--- a/src/ipcpd/normal/pol/simple_pff.c
+++ b/src/ipcpd/unicast/pol/simple_pff.c
diff --git a/src/ipcpd/normal/pol/simple_pff.h b/src/ipcpd/unicast/pol/simple_pff.h
index 08504e4e..02c09a58 100644
--- a/src/ipcpd/normal/pol/simple_pff.h
+++ b/src/ipcpd/unicast/pol/simple_pff.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_SIMPLE_PFF_H
-#define OUROBOROS_IPCPD_NORMAL_SIMPLE_PFF_H
+#ifndef OUROBOROS_IPCPD_UNICAST_SIMPLE_PFF_H
+#define OUROBOROS_IPCPD_UNICAST_SIMPLE_PFF_H
#include "pol-pff-ops.h"
@@ -54,4 +54,4 @@ int simple_pff_nhop(struct pff_i * pff_i,
struct pol_pff_ops simple_pff_ops;
-#endif /* OUROBOROS_IPCPD_NORMAL_SIMPLE_PFF_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_SIMPLE_PFF_H */
diff --git a/src/ipcpd/normal/pol/tests/CMakeLists.txt b/src/ipcpd/unicast/pol/tests/CMakeLists.txt
index d0652533..d0652533 100644
--- a/src/ipcpd/normal/pol/tests/CMakeLists.txt
+++ b/src/ipcpd/unicast/pol/tests/CMakeLists.txt
diff --git a/src/ipcpd/normal/pol/tests/graph_test.c b/src/ipcpd/unicast/pol/tests/graph_test.c
index a312c1a8..a312c1a8 100644
--- a/src/ipcpd/normal/pol/tests/graph_test.c
+++ b/src/ipcpd/unicast/pol/tests/graph_test.c
diff --git a/src/ipcpd/normal/psched.c b/src/ipcpd/unicast/psched.c
index 6e8c4e0e..6e8c4e0e 100644
--- a/src/ipcpd/normal/psched.c
+++ b/src/ipcpd/unicast/psched.c
diff --git a/src/ipcpd/normal/psched.h b/src/ipcpd/unicast/psched.h
index 3d7896cc..bc98670b 100644
--- a/src/ipcpd/normal/psched.h
+++ b/src/ipcpd/unicast/psched.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_PSCHED_H
-#define OUROBOROS_IPCPD_NORMAL_PSCHED_H
+#ifndef OUROBOROS_IPCPD_UNICAST_PSCHED_H
+#define OUROBOROS_IPCPD_UNICAST_PSCHED_H
#include <ouroboros/ipcp-dev.h>
#include <ouroboros/fqueue.h>
@@ -40,4 +40,4 @@ void psched_add(struct psched * psched,
void psched_del(struct psched * psched,
int fd);
-#endif /* OUROBOROS_IPCPD_NORMAL_PSCHED_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_PSCHED_H */
diff --git a/src/ipcpd/normal/routing.c b/src/ipcpd/unicast/routing.c
index 2cd24707..2cd24707 100644
--- a/src/ipcpd/normal/routing.c
+++ b/src/ipcpd/unicast/routing.c
diff --git a/src/ipcpd/normal/routing.h b/src/ipcpd/unicast/routing.h
index 9bbcd08b..ffded5bf 100644
--- a/src/ipcpd/normal/routing.h
+++ b/src/ipcpd/unicast/routing.h
@@ -20,8 +20,8 @@
* Foundation, Inc., http://www.fsf.org/about/contact/.
*/
-#ifndef OUROBOROS_IPCPD_NORMAL_ROUTING_H
-#define OUROBOROS_IPCPD_NORMAL_ROUTING_H
+#ifndef OUROBOROS_IPCPD_UNICAST_ROUTING_H
+#define OUROBOROS_IPCPD_UNICAST_ROUTING_H
#include <ouroboros/ipcp.h>
#include <ouroboros/qos.h>
@@ -38,4 +38,4 @@ struct routing_i * routing_i_create(struct pff * pff);
void routing_i_destroy(struct routing_i * instance);
-#endif /* OUROBOROS_IPCPD_NORMAL_ROUTING_H */
+#endif /* OUROBOROS_IPCPD_UNICAST_ROUTING_H */
diff --git a/src/ipcpd/normal/tests/CMakeLists.txt b/src/ipcpd/unicast/tests/CMakeLists.txt
index 482711d5..482711d5 100644
--- a/src/ipcpd/normal/tests/CMakeLists.txt
+++ b/src/ipcpd/unicast/tests/CMakeLists.txt
diff --git a/src/ipcpd/normal/tests/dht_test.c b/src/ipcpd/unicast/tests/dht_test.c
index 26e9102e..26e9102e 100644
--- a/src/ipcpd/normal/tests/dht_test.c
+++ b/src/ipcpd/unicast/tests/dht_test.c
diff --git a/src/ipcpd/normal/main.c b/src/ipcpd/unicast/main.c
index 28fc8c5a..c159b26d 100644
--- a/src/ipcpd/normal/main.c
+++ b/src/ipcpd/unicast/main.c
@@ -1,7 +1,7 @@
/*
* Ouroboros - Copyright (C) 2016 - 2019
*
* Normal IPC Process
*
* Dimitri Staessens <dimitri.staessens@ugent.be>
* Sander Vrijders <sander.vrijders@ugent.be>
@@ -28,7 +28,7 @@
#include "config.h"
-#define OUROBOROS_PREFIX "normal-ipcp"
+#define OUROBOROS_PREFIX "unicast-ipcp"
#include <ouroboros/errno.h>
#include <ouroboros/hash.h>
@@ -53,7 +53,7 @@
#include <assert.h>
#include <inttypes.h>
-#define THIS_TYPE IPCP_NORMAL
+#define THIS_TYPE IPCP_UNICAST
static int initialize_components(const struct ipcp_config * conf)
{
@@ -186,8 +186,8 @@ static int bootstrap_components(void)
return 0;
}
-static int normal_ipcp_enroll(const char * dst,
- struct layer_info * info)
+static int unicast_ipcp_enroll(const char * dst,
+ struct layer_info * info)
{
struct conn conn;
@@ -240,7 +240,7 @@ static int normal_ipcp_enroll(const char * dst,
return -1;
}
-static int normal_ipcp_bootstrap(const struct ipcp_config * conf)
+static int unicast_ipcp_bootstrap(const struct ipcp_config * conf)
{
assert(conf);
assert(conf->type == THIS_TYPE);
@@ -281,19 +281,19 @@ static int normal_ipcp_bootstrap(const struct ipcp_config * conf)
return -1;
}
-static int normal_ipcp_query(const uint8_t * dst)
+static int unicast_ipcp_query(const uint8_t * dst)
{
return dir_query(dst) ? 0 : -1;
}
-static struct ipcp_ops normal_ops = {
- .ipcp_bootstrap = normal_ipcp_bootstrap,
- .ipcp_enroll = normal_ipcp_enroll,
+static struct ipcp_ops unicast_ops = {
+ .ipcp_bootstrap = unicast_ipcp_bootstrap,
+ .ipcp_enroll = unicast_ipcp_enroll,
.ipcp_connect = connmgr_ipcp_connect,
.ipcp_disconnect = connmgr_ipcp_disconnect,
.ipcp_reg = dir_reg,
.ipcp_unreg = dir_unreg,
- .ipcp_query = normal_ipcp_query,
+ .ipcp_query = unicast_ipcp_query,
.ipcp_flow_alloc = fa_alloc,
.ipcp_flow_join = NULL,
.ipcp_flow_alloc_resp = fa_alloc_resp,
@@ -303,7 +303,7 @@ static struct ipcp_ops normal_ops = {
int main(int argc,
char * argv[])
{
- if (ipcp_init(argc, argv, &normal_ops) < 0) {
+ if (ipcp_init(argc, argv, &unicast_ops) < 0) {
log_err("Failed to init IPCP.");
goto fail_init;
}
@@ -1,7 +1,7 @@
* Ouroboros - Copyright (C) 2016 - 2019
*
- * Normal IPC Process
+ * Unicast IPC Process
*
* Dimitri Staessens <dimitri.staessens@ugent.be>